package frc.robot.utilities;

import edu.wpi.first.math.geometry.Pose2d;
import edu.wpi.first.math.geometry.Rotation2d;
import edu.wpi.first.util.sendable.Sendable;
import edu.wpi.first.util.sendable.SendableBuilder;

public class PoseSendable implements Sendable {

    private double x;
    private double y;
    private double rot;

    public PoseSendable() {
        this(0, 0, 0);
    }

    public PoseSendable(double x, double y, double rot) {
        this.x = x;
        this.y = y;
        this.rot = rot;
    }

    public double getX() {
        return x;
    }

    public double getY() {
        return y;
    }

    public double getRotation() {
        return rot;
    }

    public Rotation2d getRotation2d() {
        return Rotation2d.fromDegrees(rot);
    }

    public Pose2d getPose() {
        return new Pose2d(x, y, getRotation2d());
    }

    public void setX(double x) {
        this.x = x;
    }

    public void setY(double y) {
        this.y = y;
    }

    public void setRotation(double rot) {
        this.rot = rot;
    }

    @Override
    public void initSendable(SendableBuilder builder) {
        builder.addDoubleProperty("X", this::getX, this::setX);
        builder.addDoubleProperty("Y", this::getY, this::setY);
        builder.addDoubleProperty("Rotation", this::getRotation, this::setRotation);
    }
}
